@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _IsSpouseOfFilterMatch.py 14091 2010-01-18 04:42:17Z pez4brian $
+# $Id: _IsSpouseOfFilterMatch.py 15856 2010-09-03 22:56:33Z bmcage $
 
 #-------------------------------------------------------------------------
 #
@@ -32,6 +32,7 @@ from gen.ggettext import gettext as _
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
+from Filters.Rules import Rule
 from _MatchesFilter import MatchesFilter
 
 #-------------------------------------------------------------------------
@@ -39,7 +40,7 @@ from _MatchesFilter import MatchesFilter
 # IsSpouseOfFilterMatch
 #
 #-------------------------------------------------------------------------
-class IsSpouseOfFilterMatch(MatchesFilter):
+class IsSpouseOfFilterMatch(Rule):
     """Rule that checks for a person married to someone matching
     a filter"""
 
@@ -50,16 +51,21 @@ class IsSpouseOfFilterMatch(MatchesFilter):
 
     def prepare(self,db):
         self.filt = MatchesFilter (self.list)
-        self.filt.prepare(db)
+        self.filt.requestprepare(db)
         
     def apply(self,db,person):
         for family_handle in person.get_family_handle_list ():
             family = db.get_family_from_handle(family_handle)
-            for spouse_id in [family.get_father_handle (), family.get_mother_handle ()]:
-                if not spouse_id:
-                    continue
-                if spouse_id == person.handle:
-                    continue
-                if self.filt.apply (db, db.get_person_from_handle( spouse_id)):
-                    return True
+            if family:
+                for spouse_id in [family.get_father_handle(), 
+                                  family.get_mother_handle()]:
+                    if not spouse_id:
+                        continue
+                    if spouse_id == person.handle:
+                        continue
+                    if self.filt.apply (db, db.get_person_from_handle( spouse_id)):
+                        return True
         return False
+
+    def reset(self):
+        self.filt.requestreset()
