@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 9928 2008-01-24 20:38:10Z acraphae $
+# $Id: __init__.py 11605 2009-01-10 18:41:16Z dsblank $
 
 """
 Package providing filter rules for GRAMPS.
@@ -33,6 +33,7 @@ from _HasReferenceCountOf import HasReferenceCountOf
 from _RepoPrivate import RepoPrivate
 from _MatchesFilter import MatchesFilter
 from _HasRepo import HasRepo
+from _ChangedSince import ChangedSince
 
 editor_rule_list = [
     AllRepos,
@@ -43,4 +44,5 @@ editor_rule_list = [
     HasReferenceCountOf,
     RepoPrivate,
     MatchesFilter,
+    ChangedSince,
 ]
