@@ -19,7 +19,7 @@
 #
 import gobject
 
-# $Id: _SearchBar.py 12560 2009-05-21 17:58:31Z gbritton $
+# $Id: _SearchBar.py 16104 2010-11-01 20:48:23Z bmcage $
 
 """
 Package providing filtering framework for GRAMPS.
@@ -31,7 +31,7 @@ Package providing filtering framework for GRAMPS.
 #
 #-------------------------------------------------------------------------
 import gtk
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 _RETURN = gtk.gdk.keyval_from_name("Return")
 _KP_ENTER = gtk.gdk.keyval_from_name("KP_Enter")
@@ -57,7 +57,15 @@ class SearchBar(object):
         self.filter_model = gtk.ListStore(gobject.TYPE_STRING, 
                                           gobject.TYPE_INT, 
                                           gobject.TYPE_BOOLEAN)
-        
+
+    def destroy(self):
+        """Unset all things that can block garbage collection.
+        """
+        self.on_apply_callback = None
+        self.apply_done_callback = None
+        self.dbstate = None
+        self.uistate =  None
+
     def build( self):
         self.filterbar.set_spacing(4)
         self.filter_list.connect('changed', self.filter_changed)
@@ -79,6 +87,10 @@ class SearchBar(object):
         return self.filterbar
         
     def setup_filter( self, column_data ):
+        """
+        column_data is a list of tuples:
+        [(trans_col_name, index, use_exact), ...]
+        """
         self.filter_model.clear()
         old_value = self.filter_list.get_active()
         
@@ -88,11 +100,17 @@ class SearchBar(object):
         self.filter_list.add_attribute(cell, 'text', 0)
 
         maxval = 0
-        for col, index in column_data:
-            rule = _("%s contains") % col
+        for col, index, exact in column_data:
+            if exact:
+                rule = _("%s is") % col
+            else:
+                rule = _("%s contains") % col
             self.filter_model.append(row=[rule, index, False])
             maxval += 1
-            rule = _("%s does not contain") % col
+            if exact:
+                rule = _("%s is not") % col
+            else:
+                rule = _("%s does not contain") % col
             self.filter_model.append(row=[rule, index, True])
             maxval += 1
             
