@@ -20,7 +20,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _GuiOptions.py 14553 2010-03-01 19:17:59Z nick-h $
+# $Id: _GuiOptions.py 15939 2010-09-30 10:02:41Z ldnp $
 
 """
 Specific option handling for a GUI.
@@ -700,9 +700,7 @@ class GuiNoteOption(gtk.HBox):
         """
         if note:
             note_id = note.get_gramps_id()
-            txt = " ".join(note.get().split())
-            #String must be unicode for truncation to work for non ascii characters
-            txt = unicode(txt)
+            txt = u" ".join(note.get().split())
             if len(txt) > 35:
                 txt = txt[:35] + "..."
             txt = "%s [%s]" % (txt, note_id)
@@ -1277,7 +1275,7 @@ class GuiDestinationOption(gtk.HBox):
 
         status = fcd.run()
         if status == gtk.RESPONSE_OK:
-            path = Utils.get_unicode_path(fcd.get_filename())
+            path = Utils.get_unicode_path_from_file_chooser(fcd.get_filename())
             if path:
                 if not self.__option.get_directory_entry() and \
                    not path.endswith(self.__option.get_extension()):
