@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: QuestionDialog.py 15132 2010-04-15 06:41:10Z ldnp $
+# $Id: QuestionDialog.py 16181 2010-11-11 16:56:56Z ldnp $
 
 #-------------------------------------------------------------------------
 #
@@ -187,7 +187,7 @@ class ErrorDialog(gtk.MessageDialog):
 
 class RunDatabaseRepair(ErrorDialog):
     def __init__(self, msg, parent=None):
-        msg = unicode(msg.decode(sys.getfilesystemencoding()))
+        msg = unicode(str(msg).decode(sys.getfilesystemencoding()))
         ErrorDialog.__init__(
             self,
             _('Error detected in database'),
@@ -199,7 +199,7 @@ class RunDatabaseRepair(ErrorDialog):
 
 class DBErrorDialog(ErrorDialog):
     def __init__(self, msg, parent=None):
-        msg = unicode(msg.decode(sys.getfilesystemencoding()))
+        msg = unicode(str(msg).decode(sys.getfilesystemencoding()))
         ErrorDialog.__init__(
             self,
             _("Low level database corruption detected"),
