@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: read.py 14176 2010-02-01 07:01:45Z bmcage $
+# $Id: read.py 16092 2010-10-31 08:38:05Z bmcage $
 
 """
 Read classes for the GRAMPS databases.
@@ -92,6 +92,9 @@ class DbBookmarks(object):
     def insert(self, pos, item):
         self.bookmarks.insert(pos, item)
 
+    def close(self):
+        del self.bookmarks
+
 #-------------------------------------------------------------------------
 #
 # GrampsDBReadCursor
@@ -169,7 +172,6 @@ class DbBsddbRead(DbReadBase, Callback):
         """
         Create a new DbBsddbRead instance. 
         """
-        
         DbReadBase.__init__(self)
         Callback.__init__(self)
 
@@ -379,8 +381,24 @@ class DbBsddbRead(DbReadBase, Callback):
         
         The method needs to be overridden in the derived class.
         """
-        pass
-        
+        #remove links to functions
+        self.disconnect_all()
+        for key in self._tables:
+            for subkey in self._tables[key]:
+                self._tables[key][subkey] = None
+            del self._tables[key][subkey]
+            self._tables[key] = None
+        del self._tables
+##        self.bookmarks = None
+##        self.family_bookmarks = None
+##        self.event_bookmarks = None
+##        self.place_bookmarks = None
+##        self.source_bookmarks = None
+##        self.repo_bookmarks = None
+##        self.media_bookmarks = None
+##        self.note_bookmarks = None
+
+
     def is_open(self):
         """
         Return 1 if the database has been opened.
@@ -411,71 +429,80 @@ class DbBsddbRead(DbReadBase, Callback):
             map_index += 1
             index = prefix % map_index
         map_index += 1
-        return index
+        return (map_index, index)
         
     def find_next_person_gramps_id(self):
         """
         Return the next available GRAMPS' ID for a Person object based off the 
         person ID prefix.
         """
-        return self.__find_next_gramps_id(self.person_prefix,
+        self.pmap_index, gid = self.__find_next_gramps_id(self.person_prefix,
                                           self.pmap_index, self.id_trans)
+        return gid
 
     def find_next_place_gramps_id(self):
         """
         Return the next available GRAMPS' ID for a Place object based off the 
         place ID prefix.
         """
-        return self.__find_next_gramps_id(self.place_prefix,
+        self.lmap_index, gid = self.__find_next_gramps_id(self.place_prefix,
                                           self.lmap_index, self.pid_trans)
+        return gid
 
     def find_next_event_gramps_id(self):
         """
         Return the next available GRAMPS' ID for a Event object based off the 
         event ID prefix.
         """
-        return self.__find_next_gramps_id(self.event_prefix,
+        self.emap_index, gid = self.__find_next_gramps_id(self.event_prefix,
                                           self.emap_index, self.eid_trans)
+        return gid
 
     def find_next_object_gramps_id(self):
         """
         Return the next available GRAMPS' ID for a MediaObject object based
         off the media object ID prefix.
         """
-        return self.__find_next_gramps_id(self.mediaobject_prefix,
-                                          self.omap_index, self.oid_trans)        
+        self.omap_index, gid = self.__find_next_gramps_id(self.mediaobject_prefix,
+                                          self.omap_index, self.oid_trans)
+        return gid
 
     def find_next_source_gramps_id(self):
         """
         Return the next available GRAMPS' ID for a Source object based off the 
         source ID prefix.
         """
-        return self.__find_next_gramps_id(self.source_prefix,
+        self.smap_index, gid = self.__find_next_gramps_id(self.source_prefix,
                                           self.smap_index, self.sid_trans)
+        return gid
 
     def find_next_family_gramps_id(self):
         """
         Return the next available GRAMPS' ID for a Family object based off the 
         family ID prefix.
         """
-        return self.__find_next_gramps_id(self.family_prefix,
+        self.fmap_index, gid = self.__find_next_gramps_id(self.family_prefix,
                                           self.fmap_index, self.fid_trans)
+        return gid
 
     def find_next_repository_gramps_id(self):
         """
         Return the next available GRAMPS' ID for a Respository object based 
         off the repository ID prefix.
         """
-        return self.__find_next_gramps_id(self.repository_prefix,
-                                          self.rmap_index, self.rid_trans)        
+        self.rmap_index, gid = self.__find_next_gramps_id(self.repository_prefix,
+                                          self.rmap_index, self.rid_trans)
+        return gid
 
     def find_next_note_gramps_id(self):
         """
         Return the next available GRAMPS' ID for a Note object based off the 
         note ID prefix.
         """
-        return self.__find_next_gramps_id(self.note_prefix,
-                                          self.nmap_index, self.nid_trans)          
+        self.nmap_index, gid = self.__find_next_gramps_id(self.note_prefix,
+                                          self.nmap_index, self.nid_trans)
+        return gid
+
     def get_from_handle(self, handle, class_type, data_map):
         data = data_map.get(str(handle))
         if data:
