@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: date.py 12560 2009-05-21 17:58:31Z gbritton $
+# $Id: date.py 14145 2010-01-27 03:38:30Z pez4brian $
 
 """Support for dates."""
 
@@ -28,8 +28,8 @@
 # Python modules
 #
 #------------------------------------------------------------------------
-from TransUtils import sgettext as _
-from gettext import ngettext
+from gen.ggettext import sgettext as _
+from gen.ggettext import ngettext
 
 #------------------------------------------------------------------------
 #
@@ -57,7 +57,7 @@ from gen.lib.calendar import (gregorian_sdn, julian_sdn, hebrew_sdn,
                               gregorian_ymd, julian_ymd, hebrew_ymd, 
                               french_ymd, persian_ymd, islamic_ymd,
                               swedish_ymd)
-import Config
+import config
 
 #-------------------------------------------------------------------------
 #
@@ -82,9 +82,9 @@ class Span(object):
     minmax = (min days, max days)
 
     """
-    BEFORE = Config.get(Config.DATE_BEFORE_RANGE)
-    AFTER  = Config.get(Config.DATE_AFTER_RANGE)
-    ABOUT  = Config.get(Config.DATE_ABOUT_RANGE)
+    BEFORE = config.get('behavior.date-before-range')
+    AFTER  = config.get('behavior.date-after-range')
+    ABOUT  = config.get('behavior.date-about-range')
     def __init__(self, date1, date2):
         self.valid = (date1.sortval != 0 and date2.sortval != 0)
         self.date1 = date1
@@ -269,18 +269,25 @@ class Span(object):
         return self._diff(self.date1, self.date2)[pos]
 
     def __int__(self):
+        """
+        Returns the number of days of span.
+        """
         if self.negative:
-            return -self.sort[0]
+            return -(self.sort[0] + self.sort[1])
         else:
-            return self.sort[0]
+            return  (self.sort[0] + self.sort[1])
 
     def __cmp__(self, other):
+        """
+        Comparing two Spans for SORTING purposes. 
+        Use cmp(abs(int(span1)), abs(int(span2))) for comparing
+        actual spans of times, as spans have directionality 
+        as indicated by negative values.
+        """
         if other is None:
-            return cmp(self.sort, (-9999, -9999))
-        elif self.negative:
-            return cmp((-self.sort[0], self.sort[1]), other.sort)
+            return cmp(int(self), -9999)
         else:
-            return cmp(self.sort, other.sort)
+            return cmp(int(self), int(other))
 
     def __repr__(self):
         if self.repr is not None:
@@ -446,27 +453,27 @@ class Span(object):
 
     def __eq__(self, other):
         """
-        For comparing of Spans. Uses the sort tuple pair.
+        For comparing of Spans. Uses the integer representation.
         """
         if other is None:
             return False
-        return self.sort == other.sort
+        return int(self) == int(other)
 
     def __lt__(self, other):
         """
-        For less-than comparing of Spans. Uses the sort tuple pair.
+        For less-than comparing of Spans. Uses the integer representation.
         """
         if other is None:
             return False
-        return self.sort < other.sort
+        return int(self) < int(other)
 
     def __gt__(self, other):
         """
-        For greater-than comparing of Spans. Uses the sort tuple pair.
+        For greater-than comparing of Spans. Uses the integer representation.
         """
         if other is None:
             return True
-        return self.sort > other.sort
+        return int(self) > int(other)
 
     def format(self, precision=2):
         """
@@ -561,7 +568,7 @@ class Span(object):
                 diff = 0
                 while eDate >> date2 and diff > -60:
                     diff -= 1
-                    eDate = eDate - (0, 0, abs(diff))
+                    eDate -= (0, 0, abs(diff))
                 if diff == -60:
                     return (-1, -1, -1)
                 if self.negative:
@@ -650,21 +657,18 @@ class Date(object):
                       "Swedish"]
 
 
-    ui_calendar_names = [_("Gregorian"), 
-                         _("Julian"), 
-                         _("Hebrew"), 
-                         _("French Republican"), 
-                         _("Persian"), 
-                         _("Islamic"),
-                         _("Swedish")]
+    ui_calendar_names = [_("calendar|Gregorian"), 
+                         _("calendar|Julian"), 
+                         _("calendar|Hebrew"), 
+                         _("calendar|French Republican"), 
+                         _("calendar|Persian"), 
+                         _("calendar|Islamic"),
+                         _("calendar|Swedish")]
 
-    def __init__(self, *source, **kwargs):
+    def __init__(self, *source):
         """
         Create a new Date instance.
         """
-        calendar = kwargs.get("calendar", None)
-        modifier = kwargs.get("modifier", None)
-        quality = kwargs.get("quality", None)
         #### setup None, Date, or numbers
         if len(source) == 0:
             source = None
@@ -681,40 +685,14 @@ class Date(object):
             raise AttributeError, "invalid args to Date: %s" % source
         #### ok, process either date or tuple
         if isinstance(source, tuple):
-            if calendar is None:
-                self.calendar = Date.CAL_GREGORIAN
-            elif isinstance(calendar, int):
-                self.calendar = calendar
-            else:
-                self.calendar = self.lookup_calendar(calendar)
-            if modifier is None:
-                self.modifier = Date.MOD_NONE
-            else:
-                self.modifier = self.lookup_modifier(modifier)
-            if quality is None:
-                self.quality  = Date.QUAL_NONE
-            else:
-                self.quality = self.lookup_quality(quality)
+            self.calendar = Date.CAL_GREGORIAN
+            self.modifier = Date.MOD_NONE
+            self.quality  = Date.QUAL_NONE
             self.dateval  = Date.EMPTY
             self.text     = u""
             self.sortval  = 0
             self.newyear = 0
             self.set_yr_mon_day(*source)
-        elif isinstance(source, str) and source != "":
-            if (calendar is not None or 
-                modifier is not None or 
-                quality is not None):
-                raise AttributeError("can't set calendar, modifier, or "
-                                     "quality with string date")
-            import DateHandler
-            source = DateHandler.parser.parse(source)
-            self.calendar = source.calendar
-            self.modifier = source.modifier
-            self.quality  = source.quality
-            self.dateval  = source.dateval
-            self.text     = source.text
-            self.sortval  = source.sortval
-            self.newyear  = source.newyear
         elif source:
             self.calendar = source.calendar
             self.modifier = source.modifier
@@ -900,12 +878,13 @@ class Date(object):
             (year,month,day) in the Gregorian calendar.
             """
             new_date = Date()
-            new_date.set_yr_mon_day(dateval[0], dateval[1], dateval[2])
+            new_date.set_yr_mon_day(*dateval[:3])
             return new_date.offset(offset)
         
-        datecopy = Date(self)
+        datecopy = Date(self) 
         #we do all calculation in Gregorian calendar
         datecopy.convert_calendar(Date.CAL_GREGORIAN)
+
         start     = yr_mon_day(datecopy.get_start_date())
         stop      = yr_mon_day(datecopy.get_stop_date())
 
@@ -927,15 +906,15 @@ class Date(object):
         # if BEFORE, AFTER, or ABOUT/EST, adjust:
         if self.modifier == Date.MOD_BEFORE:
             stopmax = date_offset(startmin, -1)
-            fdiff = Config.get(Config.DATE_BEFORE_RANGE)
+            fdiff = config.get('behavior.date-before-range')
             startmin = (stopmax[0] - fdiff, stopmax[1], stopmax[2])
         elif self.modifier == Date.MOD_AFTER:
             startmin = date_offset(stopmax, 1)
-            fdiff = Config.get(Config.DATE_AFTER_RANGE)
+            fdiff = config.get('behavior.date-after-range')
             stopmax = (startmin[0] + fdiff, startmin[1], startmin[2])
         elif (self.modifier == Date.MOD_ABOUT or
               self.quality == Date.QUAL_ESTIMATED):
-            fdiff = Config.get(Config.DATE_ABOUT_RANGE)
+            fdiff = config.get('behavior.date-about-range')
             startmin = (startmin[0] - fdiff, startmin[1], startmin[2])
             stopmax = (stopmax[0] + fdiff, stopmax[1], stopmax[2])
         # return tuples not lists, for comparisons
@@ -963,8 +942,10 @@ class Date(object):
         """
         if (other_date.modifier == Date.MOD_TEXTONLY or
             self.modifier == Date.MOD_TEXTONLY):
-            if comparison in ["=", "=="]:
+            if comparison == "=":
                 return (self.text.upper().find(other_date.text.upper()) != -1)
+            elif comparison == "==":
+                return self.text == other_date.text
             else:
                 return False
         if (self.sortval == 0 or other_date.sortval == 0):
@@ -974,21 +955,31 @@ class Date(object):
         other_start, other_stop = other_date.get_start_stop_range()
         self_start,  self_stop  = self.get_start_stop_range()
 
-        if comparison in ["=", "=="]:
+        if comparison == "=":
             # If some overlap then match is True, otherwise False.
             return ((self_start <= other_start <= self_stop) or
                     (self_start <= other_stop <= self_stop) or 
                     (other_start <= self_start <= other_stop) or 
                     (other_start <= self_stop <= other_stop))
+        elif comparison == "==":
+            # If they match exactly on start and stop
+            return ((self_start == other_start) and
+                    (other_stop == other_stop))
         elif comparison == "<":
             # If any < any
             return self_start < other_stop
+        elif comparison == "<=":
+            # If any < any
+            return self_start <= other_stop
         elif comparison == "<<":
             # If all < all
             return self_stop < other_start
         elif comparison == ">":
             # If any > any
             return self_stop > other_start
+        elif comparison == ">=":
+            # If any > any
+            return self_stop >= other_start
         elif comparison == ">>":
             # If all > all
             return self_start > other_stop
@@ -1021,11 +1012,28 @@ class Date(object):
         else:
             pref = ""
 
-        if self.calendar != Date.CAL_GREGORIAN:
-            cal = " (%s)" % Date.calendar_names[self.calendar]
+        if self.newyear == Date.NEWYEAR_JAN1:
+            ny = ""
+        elif self.newyear == Date.NEWYEAR_MAR1:
+            ny = "Mar1"
+        elif self.newyear == Date.NEWYEAR_MAR25:
+            ny = "Mar25"
+        elif self.newyear == Date.NEWYEAR_SEP1:
+            ny = "Sep1"
         else:
-            cal = ""
+            ny = "Err"
             
+        if self.calendar != Date.CAL_GREGORIAN:
+            if ny:
+                cal = " (%s,%s)" % (Date.calendar_names[self.calendar], ny)
+            else:
+                cal = " (%s)" % Date.calendar_names[self.calendar]
+        else:
+            if ny:
+                cal = " (%s)" % ny
+            else:
+                cal = ""
+
         if self.modifier == Date.MOD_TEXTONLY:
             val = self.text
         elif self.get_slash():
@@ -1200,6 +1208,26 @@ class Date(object):
         """
         return self._get_low_item(Date._POS_YR)
 
+    def get_year_calendar(self, calendar_name=None):
+        """
+        Return the year of this date in the calendar name given. 
+
+        Defaults to self's calendar if one is not given.
+
+        >>> Date(2009, 12, 8).to_calendar("hebrew").get_year_calendar()
+        5770
+        """
+        if calendar_name:
+            cal = lookup_calendar(calendar_name)
+        else:
+            cal = self.calendar
+        if cal == self.calendar:
+            return self.get_year()
+        else:
+            retval = Date(self)
+            retval.convert_calendar(cal)
+            return retval.get_year()
+
     def get_new_year(self):
         """
         Return the new year code associated with the date. 
@@ -1452,13 +1480,21 @@ class Date(object):
             elif ny == Date.NEWYEAR_SEP1:
                 split = (9, 1)
             if (self.get_month(), self.get_day()) >= split:
-                d1 = Date(self.get_year(), 1, 1, calendar=self.calendar).sortval
-                d2 = Date(self.get_year(), split[0], split[1], calendar=self.calendar).sortval
-                self.sortval -= (d2 - d1)
+                d1 = Date(self.get_year(), 1, 1)
+                d1.set_calendar(self.calendar)
+                d1_val = d1.sortval
+                d2 = Date(self.get_year(), split[0], split[1])
+                d2.set_calendar(self.calendar)
+                d2_val = d2.sortval
+                self.sortval -= (d2_val - d1_val)
             else:
-                d1 = Date(self.get_year(), 12, 31, calendar=self.calendar).sortval
-                d2 = Date(self.get_year(), split[0], split[1], calendar=self.calendar).sortval
-                self.sortval += (d1 - d2) + 1
+                d1 = Date(self.get_year(), 12, 31)
+                d1.set_calendar(self.calendar)
+                d1_val = d1.sortval
+                d2 = Date(self.get_year(), split[0], split[1])
+                d2.set_calendar(self.calendar)
+                d2_val = d2.sortval
+                self.sortval += (d1_val - d2_val) + 1
 
         if text:
             self.text = text
@@ -1488,7 +1524,7 @@ class Date(object):
         """
         Convert the date from the current calendar to the specified calendar.
         """
-        if calendar == self.calendar:
+        if calendar == self.calendar and self.newyear == Date.NEWYEAR_JAN1:
             return
         (year, month, day) = Date._calendar_change[calendar](self.sortval)
         if self.is_compound():
@@ -1497,11 +1533,12 @@ class Date(object):
             rday = max(self.dateval[Date._POS_RDAY], 1)
             sdn = Date._calendar_convert[self.calendar](ryear, rmonth, rday)
             (nyear, nmonth, nday) = Date._calendar_change[calendar](sdn)
-            self.dateval = (day, month, year, self.dateval[Date._POS_SL], 
-                            nday, nmonth, nyear, self.dateval[Date._POS_RSL])
+            self.dateval = (day, month, year, False, 
+                            nday, nmonth, nyear, False)
         else:
-            self.dateval = (day, month, year, self.dateval[Date._POS_SL])
+            self.dateval = (day, month, year, False)
         self.calendar = calendar
+        self.newyear = Date.NEWYEAR_JAN1
 
     def set_as_text(self, text):
         """
@@ -1573,14 +1610,7 @@ class Date(object):
         """
         Lookup calendar name in the list of known calendars, even if translated.
         """
-        calendar_lower = [n.lower() for n in Date.calendar_names]
-        ui_lower = [n.lower() for n in Date.ui_calendar_names]
-        if calendar.lower() in calendar_lower:
-            return calendar_lower.index(calendar.lower())
-        elif calendar.lower() in ui_lower:
-            return ui_lower.index(calendar.lower())
-        else:
-            raise AttributeError("invalid calendar: '%s'" % calendar)
+        return lookup_calendar(calendar)
 
     def lookup_quality(self, quality):
         """
@@ -1614,10 +1644,10 @@ class Date(object):
         """
         Return a new Date object in the calendar calendar_name.
         
-        >>> Date("Jan 1 1591").to_calendar("julian")
+        >>> Date(1591, 1, 1).to_calendar("julian")
         1590-12-22 (Julian)
         """
-        cal = self.lookup_calendar(calendar_name)
+        cal = lookup_calendar(calendar_name)
         retval = Date(self)
         retval.convert_calendar(cal)
         return retval
@@ -1632,7 +1662,36 @@ class Date(object):
         """
         Set to 1 if the date is a slash-date (dual dated).
         """
-        self.dateval[Date._POS_SL] = value
+        temp = list(self.dateval)
+        temp[Date._POS_SL] = value
+        self.dateval = tuple(temp)
+
+    def get_slash2(self):
+        """
+        Return true if the ending date is a slash-date (dual dated).
+        """
+        return self._get_low_item_valid(Date._POS_RSL)
+
+    def set_slash2(self, value):
+        """
+        Set to 1 if the ending date is a slash-date (dual dated).
+        """
+        temp = list(self.dateval)
+        temp[Date._POS_RSL] = value
+        self.dateval = tuple(temp)
+
+    def make_vague(self):
+        """
+        Remove month and day details to make the date approximate.
+        """
+        dv = list(self.dateval)
+        dv[Date._POS_MON] = 0
+        dv[Date._POS_DAY] = 0
+        if Date._POS_RDAY < len(dv):
+            dv[Date._POS_RDAY] = 0
+            dv[Date._POS_RMON] = 0
+        self.dateval = tuple(dv)
+        self._calc_sort_value()
 
 def Today():
     """
@@ -1643,3 +1702,26 @@ def Today():
     current_date.set_yr_mon_day(*time.localtime(time.time())[0:3])
     return current_date
 
+#-------------------------------------------------------------------------
+#
+# Date Functions
+#
+#-------------------------------------------------------------------------
+
+
+def lookup_calendar(calendar):
+    """
+    Find the ID associated with the calendar name.
+
+    >>> lookup_calendar("hebrew")
+    2
+    """
+    if calendar is None: return Date.CAL_GREGORIAN
+    if isinstance(calendar, int): return calendar
+    for pos, calendar_name in enumerate(Date.calendar_names):
+        if calendar.lower() == calendar_name.lower():
+            return pos
+    for pos, calendar_name in enumerate(Date.ui_calendar_names):
+        if calendar.lower() == calendar_name.lower():
+            return pos
+    raise AttributeError("invalid calendar: '%s'" % calendar)
