@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ldsordbase.py 12560 2009-05-21 17:58:31Z gbritton $
+# $Id: ldsordbase.py 14191 2010-02-02 13:56:15Z gbritton $
 
 """
 LdsOrdBase class for GRAMPS.
@@ -48,8 +48,8 @@ class LdsOrdBase(object):
         If the source is not None, then object is initialized from values of 
         the source object.
 
-        @param source: Object used to initialize the new object
-        @type source: LdsOrdBase
+        :param source: Object used to initialize the new object
+        :type source: LdsOrdBase
         """
         
         if source:
@@ -72,24 +72,24 @@ class LdsOrdBase(object):
 
     def add_lds_ord(self, lds_ord):
         """
-        Add the L{LdsOrd} instance to the object's list of lds_ordes.
+        Add the :class:`~gen.lib.ldsord.LdsOrd` instance to the object's list of lds_ordes.
 
-        @param lds_ord: L{LdsOrd} instance to add to the object's lds_ord list
-        @type lds_ord: list
+        :param lds_ord: :class:`~gen.lib.ldsord.LdsOrd` instance to add to the object's lds_ord list
+        :type lds_ord: list
         """
         self.lds_ord_list.append(lds_ord)
 
     def remove_lds_ord(self, lds_ord):
         """
-        Remove the specified L{LdsOrd} instance from the lds_ord list.
+        Remove the specified :class:`~gen.lib.ldsord.LdsOrd` instance from the lds_ord list.
         
         If the instance does not exist in the list, the operation has no effect.
 
-        @param lds_ord: L{LdsOrd} instance to remove from the list
-        @type lds_ord: L{LdsOrd}
+        :param lds_ord: :class:`~gen.lib.ldsord.LdsOrd` instance to remove from the list
+        :type lds_ord: :class:`~gen.lib.ldsord.LdsOrd`
 
-        @return: True if the lds_ord was removed, False if it was not in the list.
-        @rtype: bool
+        :returns: True if the lds_ord was removed, False if it was not in the list.
+        :rtype: bool
         """
         if lds_ord in self.lds_ord_list:
             self.lds_ord_list.remove(lds_ord)
@@ -99,19 +99,19 @@ class LdsOrdBase(object):
 
     def get_lds_ord_list(self):
         """
-        Return the list of L{LdsOrd} instances associated with the object.
+        Return the list of :class:`~gen.lib.ldsord.LdsOrd` instances associated with the object.
 
-        @return: Returns the list of L{LdsOrd} instances
-        @rtype: list
+        :returns: Returns the list of :class:`~gen.lib.ldsord.LdsOrd` instances
+        :rtype: list
         """
         return self.lds_ord_list
 
     def set_lds_ord_list(self, lds_ord_list):
         """
-        Assign the passed list to the object's list of L{LdsOrd} instances.
+        Assign the passed list to the object's list of :class:`~gen.lib.ldsord.LdsOrd` instances.
         
-        @param lds_ord_list: List of L{LdsOrd} instances to be associated
+        :param lds_ord_list: List of :class:`~gen.lib.ldsord.LdsOrd` instances to be associated
             with the object
-        @type lds_ord_list: list
+        :type lds_ord_list: list
         """
         self.lds_ord_list = lds_ord_list
