@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: locationbase.py 12560 2009-05-21 17:58:31Z gbritton $
+# $Id: locationbase.py 12704 2009-06-24 21:56:07Z bmcage $
 
 """
 LocationBase class for GRAMPS.
@@ -75,8 +75,8 @@ class LocationBase(object):
         """
         Return the list of all textual attributes of the object.
 
-        @return: Returns the list of all textual attributes of the object.
-        @rtype: list
+        :returns: Returns the list of all textual attributes of the object.
+        :rtype: list
         """
         return [self.city, self.state, self.country, self.postal, self.phone]
 
