@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _pluginreg.py 14888 2010-03-21 10:32:36Z bmcage $
+# $Id: _pluginreg.py 15939 2010-09-30 10:02:41Z ldnp $
 
 """
 This module provides the base class for plugin registration. 
@@ -955,8 +955,6 @@ class PluginRegister(object):
             lenpd = len(self.__plugindata)
             full_filename = os.path.join(dir, filename)
             local_gettext = get_addon_translator(full_filename).gettext
-            if type(full_filename) == str:
-                full_filename = unicode(full_filename, sys.getfilesystemencoding())
             try:
                 #execfile(full_filename,
                 execfile(full_filename.encode(sys.getfilesystemencoding()),
