@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: embeddedlist.py 14135 2010-01-25 17:45:21Z gbritton $
+# $Id: embeddedlist.py 16104 2010-11-01 20:48:23Z bmcage $
 
 #-------------------------------------------------------------------------
 #
@@ -69,6 +69,7 @@ class EmbeddedList(ButtonTab):
                            move_buttons, jump_button)
 
         self.changed = False
+        self.model = None
         self.build_model = build_model
 
         # handle the selection
@@ -466,6 +467,9 @@ class EmbeddedList(ButtonTab):
         selectedpath = None
         if node:
             selectedpath = model.get_path(node)
+        if self.model and hasattr(self.model, 'destroy'):
+            self.tree.set_model(None)
+            self.model.destroy()
         try:
             self.model = self.construct_model()
         except AttributeError, msg:
