@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: editname.py 15120 2010-04-14 20:15:40Z bmcage $
+# $Id: editname.py 16104 2010-11-01 20:48:23Z bmcage $
 
 #-------------------------------------------------------------------------
 #
@@ -35,6 +35,7 @@ from gen.ggettext import gettext as _
 # GTK/Gnome modules
 #
 #-------------------------------------------------------------------------
+import gobject
 import gtk
 
 #-------------------------------------------------------------------------
@@ -171,6 +172,7 @@ class EditName(EditSecondary):
             self.obj.get_sort_as,
             format_list,
             self.db.readonly)
+        self.track_ref_for_deletion("sort_as")
 
         self.display_as = MonitoredMenu(
             self.top.get_object('display_as'),
@@ -178,6 +180,7 @@ class EditName(EditSecondary):
             self.obj.get_display_as,
             format_list,
             self.db.readonly)
+        self.track_ref_for_deletion("display_as")
 
         self.given_field = MonitoredEntry(
             self.top.get_object("alt_given"),
@@ -248,16 +251,17 @@ class EditName(EditSecondary):
         notebook = self.top.get_object("notebook")
 
         self._add_tab(notebook, self.gennam)
+        self.track_ref_for_deletion("gennam")
 
-        self.srcref_list = self._add_tab(
-            notebook,
-            SourceEmbedList(self.dbstate,self.uistate,self.track,self.obj))
+        self.srcref_list = SourceEmbedList(self.dbstate,self.uistate,self.track,self.obj)
+        self._add_tab(notebook, self.srcref_list)
+        self.track_ref_for_deletion("srcref_list")
         
-        self.note_tab = self._add_tab(
-            notebook,
-            NoteTab(self.dbstate, self.uistate, self.track,
+        self.note_tab = NoteTab(self.dbstate, self.uistate, self.track,
                     self.obj.get_note_list(),
-                    notetype=NoteType.PERSONNAME))
+                    notetype=NoteType.PERSONNAME)
+        self._add_tab(notebook, self.note_tab)
+        self.track_ref_for_deletion("note_tab")
 
         self._setup_notebook_tabs( notebook)
         
@@ -423,6 +427,7 @@ class EditName(EditSecondary):
         if closeit:
             if self.callback:
                 self.callback(self.obj)
+            self.callback = None
             self.close()
 
     def _cleanup_on_exit(self):
@@ -436,3 +441,4 @@ class EditName(EditSecondary):
         # can't use group_over, see Note in gen/lib/name/Name.set_group_as().
         if not self.group_as.obj.get_editable():
             self.obj.set_group_as("")
+        EditSecondary._cleanup_on_exit(self)
