@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: editperson.py 14091 2010-01-18 04:42:17Z pez4brian $
+# $Id: editperson.py 16092 2010-10-31 08:38:05Z bmcage $
 
 """
 EditPerson Dialog. Provide the interface to allow the GRAMPS program
@@ -754,6 +754,7 @@ class EditPerson(EditPrimary):
         self.close()
         if self.callback:
             self.callback(self.obj)
+        self.callback = None
 
     def _edit_name_clicked(self, obj):
         """
@@ -763,8 +764,11 @@ class EditPerson(EditPrimary):
         on the main form (not in the names tab).
          
         """
-        EditName(self.dbstate, self.uistate, self.track, 
+        try:
+            EditName(self.dbstate, self.uistate, self.track, 
                  self.pname, self._update_name)
+        except Errors.WindowActiveError:
+            pass
 
     def _update_name(self, name):
         """
@@ -886,10 +890,14 @@ class EditPerson(EditPrimary):
         return child_ref_list
 
     def _cleanup_on_exit(self):
+        """Unset all things that can block garbage collection.
+        Finalize rest
+        """
         config.set('interface.prefix-suffix', self.prefix_suffix.active_key)
         config.set('interface.patro-title', self.patro_title.active_key)
         config.save()
 
+        EditPrimary._cleanup_on_exit(self)
 
 class GenderDialog(gtk.MessageDialog):
     def __init__(self, parent=None):
