@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: flatbasemodel.py 14969 2010-03-29 16:04:19Z nick-h $
+# $Id: flatbasemodel.py 16092 2010-10-31 08:38:05Z bmcage $
 
 """
 This module provides the flat treemodel that is used for all flat treeviews.
@@ -122,6 +122,14 @@ class FlatNodeMap(object):
         self._reverse = False
         self.__corr = (0, 1)
 
+    def destroy(self):
+        """
+        Unset all elements that can prevent garbage collection
+        """
+        self._index2hndl = None
+        self._fullhndl = None
+        self._hndl2index = None
+
     def set_path_map(self, index2hndllist, fullhndllist, identical=True,
                      reverse=False):
         """
@@ -414,6 +422,18 @@ class FlatBaseModel(gtk.GenericTreeModel):
         _LOG.debug(self.__class__.__name__ + ' __init__ ' +
                     str(time.clock() - cput) + ' sec')
 
+    def destroy(self):
+        """
+        Unset all elements that prevent garbage collection
+        """
+        self.db = None
+        self.sort_func = None
+        if self.node_map:
+            self.node_map.destroy()
+        self.node_map = None
+        self.rebuild_data = None
+        self.search = None
+
     def set_search(self, search):
         """
         Change the search function that filters the data in the model. 
