@@ -20,7 +20,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: ExportGedcom.py 15235 2010-04-19 13:49:49Z ldnp $
+# $Id: ExportGedcom.py 16031 2010-10-24 07:20:15Z romjerome $
 
 "Export to GEDCOM"
 
@@ -44,7 +44,7 @@ import libgedcom
 import Errors
 from ExportOptions import WriterOptionBox
 from gen.updatecallback import UpdateCallback
-from Utils import media_path_full, get_unicode_path
+from Utils import media_path_full
 import gen.proxy
 from QuestionDialog import ErrorDialog
 from PlaceUtils import conv_lat_lon
@@ -186,15 +186,17 @@ def breakup(txt, limit):
 #
 #-------------------------------------------------------------------------
 def event_has_subordinate_data(event, event_ref):
-    gotany = event.get_description().strip() or\
-        not event.get_date_object().is_empty() or\
-        event.get_place_handle() or\
-        event.get_attribute_list() or\
-        event_ref.get_attribute_list() or\
-        event.get_note_list() or\
-        event.get_source_references() or\
-        event.get_media_list()
-    return gotany
+    if event and event_ref:
+        return (event.get_description().strip() or
+                not event.get_date_object().is_empty() or
+                event.get_place_handle() or
+                event.get_attribute_list() or
+                event_ref.get_attribute_list() or
+                event.get_note_list() or
+                event.get_source_references() or
+                event.get_media_list())
+    else:
+        return False
 
 
 #-------------------------------------------------------------------------
@@ -330,7 +332,7 @@ class GedcomWriter(UpdateCallback):
             token_level = level
             for text in textlist:
                 # make it unicode so that breakup below does the right thin.
-                text = get_unicode_path(text)
+                text = unicode(text)
                 if limit:
                     prefix = "\n%d CONC " % (level + 1)
                     txt = prefix.join(breakup(text, limit))
@@ -388,7 +390,7 @@ class GedcomWriter(UpdateCallback):
         self.__writeln(1, "DATE", date_str)
         self.__writeln(2, "TIME", time_str)
         self.__writeln(1, "SUBM", "@SUBM@")
-        self.__writeln(1, "FILE", filename)
+        self.__writeln(1, "FILE", filename, limit=255)
         self.__writeln(1, "COPR", 'Copyright (c) %d %s.' % (year, rname))
         self.__writeln(1, "GEDC")
         self.__writeln(2, "VERS", "5.5")
@@ -467,6 +469,7 @@ class GedcomWriter(UpdateCallback):
         sorted_list = []
         for handle in phandles:
             person = self.dbase.get_person_from_handle(handle)
+            if person is None: continue
             data = (person.get_gramps_id(), handle)
             sorted_list.append(data)
         sorted_list.sort()
@@ -502,6 +505,7 @@ class GedcomWriter(UpdateCallback):
         +1 RIN <AUTOMATED_RECORD_ID> {0:1} 
         +1 <<CHANGE_DATE>> {0:1} 
         """
+        if person is None: return
         self.__writeln(0, "@%s@" % person.get_gramps_id(),  "INDI")
 
         self.__names(person)
@@ -530,6 +534,7 @@ class GedcomWriter(UpdateCallback):
         """
         for ref in person.get_person_ref_list():
             person = self.dbase.get_person_from_handle(ref.ref)
+            if person is None: continue
             self.__writeln(level, "ASSO", "@%s@" % person.get_gramps_id())
             self.__writeln(level+1, "RELA", ref.get_relation())
             self.__note_references(ref.get_note_list(), level+1)
@@ -544,6 +549,7 @@ class GedcomWriter(UpdateCallback):
         """
         for note_handle in notelist:
             note = self.dbase.get_note_from_handle(note_handle)
+            if note is None: continue
             self.__writeln(level, 'NOTE', '@%s@' % note.get_gramps_id())
 
     def __names(self, person):
@@ -603,6 +609,8 @@ class GedcomWriter(UpdateCallback):
         """
         for event_ref in person.get_event_ref_list():
             event = self.dbase.get_event_from_handle(event_ref.ref)
+            if event is None:
+                continue
             etype = int(event.get_type())
 
             # if the event is a birth or death, skip it.
@@ -610,6 +618,11 @@ class GedcomWriter(UpdateCallback):
                 continue
                 
             val = libgedcom.personalConstantEvents.get(etype, "").strip()
+            
+            role = int(event_ref.get_role())
+            
+            if role != gen.lib.EventRoleType.PRIMARY:
+                continue
                         
             if val and val.strip():
                 if val in NEEDS_PARAMETER:
@@ -758,6 +771,7 @@ class GedcomWriter(UpdateCallback):
                         for hndl in person.get_parent_family_handle_list() ]
 
         for family in family_list:
+            if family is None: continue
             self.__writeln(1, 'FAMC', '@%s@' % family.get_gramps_id())
 
     def __parent_families(self, person):
@@ -771,6 +785,7 @@ class GedcomWriter(UpdateCallback):
                         for hndl in person.get_family_handle_list() ]
 
         for family in family_list:
+            if family is None: continue
             self.__writeln(1, 'FAMS', '@%s@' % family.get_gramps_id())
 
     def __person_sources(self, person):
@@ -795,7 +810,7 @@ class GedcomWriter(UpdateCallback):
             if url.get_description():
                 self.__writeln(level+1, 'TITL', url.get_description())
             if url.get_path():
-                self.__writeln(level+1, 'FILE', url.get_path())
+                self.__writeln(level+1, 'FILE', url.get_path(), limit=255)
 
     def __families(self):
         """
@@ -828,6 +843,7 @@ class GedcomWriter(UpdateCallback):
         +1 <<LDS_SPOUSE_SEALING>> {0:M}
         +1 REFN <USER_REFERENCE_NUMBER> {0:M}
         """
+        if family is None: return
         gramps_id = family.get_gramps_id()
 
         self.__writeln(0, '@%s@' % gramps_id, 'FAM' )
@@ -853,6 +869,7 @@ class GedcomWriter(UpdateCallback):
             for cref in child_ref_list ]
 
         for gid in child_list:
+            if gid is None: continue
             self.__writeln(1, 'CHIL', '@%s@' % gid)
 
     def __family_reference(self, token, person_handle):
@@ -865,6 +882,7 @@ class GedcomWriter(UpdateCallback):
         """
         if person_handle:
             person = self.dbase.get_person_from_handle(person_handle)
+            if person is None: return
             self.__writeln(1, token, '@%s@' % person.get_gramps_id())
 
     def __family_events(self, family):
@@ -877,6 +895,7 @@ class GedcomWriter(UpdateCallback):
         """
         for event_ref in family.get_event_ref_list():
             event = self.dbase.get_event_from_handle(event_ref.ref)
+            if event is None: continue
             etype = int(event.get_type())
             val = libgedcom.familyConstantEvents.get(etype)
             
@@ -963,6 +982,7 @@ class GedcomWriter(UpdateCallback):
 
         for (source_id, handle) in sorted_list:
             source = self.dbase.get_source_from_handle(handle)
+            if source is None: continue
             self.__writeln(0, '@%s@' % source_id, 'SOUR')
             if source.get_title():
                 self.__writeln(1, 'TITL', source.get_title())
@@ -997,6 +1017,7 @@ class GedcomWriter(UpdateCallback):
 
         for note_handle in [hndl[1] for hndl in sorted_list]:
             note = self.dbase.get_note_from_handle(note_handle)
+            if note is None: continue
             self.__note_record(note)
             
     def __note_record(self, note):
@@ -1010,7 +1031,14 @@ class GedcomWriter(UpdateCallback):
         +1 <<CHANGE_DATE>> {0:1} 
         """
 
-        self.__writeln(0, '@%s@' % note.get_gramps_id(),  'NOTE ' + note.get())
+        # The note must be converted to unicode 
+        # Method stolen from ExportXml.py
+        line = note.get()
+        try:
+            line = unicode(line)
+        except:
+            line = unicode(str(line),errors='replace')
+        self.__writeln(0, '@%s@' % note.get_gramps_id(),  'NOTE ' + line)
 
     def __repos(self):
         """
@@ -1036,6 +1064,7 @@ class GedcomWriter(UpdateCallback):
 
         for (repo_id, handle) in sorted_list:
             repo = self.dbase.get_repository_from_handle(handle)
+            if repo is None: continue
             self.__writeln(0, '@%s@' % repo_id, 'REPO' )
             if repo.get_name():
                 self.__writeln(1, 'NAME', repo.get_name())
@@ -1065,6 +1094,8 @@ class GedcomWriter(UpdateCallback):
             return
 
         repo = self.dbase.get_repository_from_handle(reporef.ref)
+        if repo is None:
+            return
         repo_id = repo.get_gramps_id()
 
         self.__writeln(level, 'REPO', '@%s@' % repo_id )
@@ -1082,13 +1113,14 @@ class GedcomWriter(UpdateCallback):
         """
         if event_ref:
             event = self.dbase.get_event_from_handle(event_ref.ref)
-            if event_has_subordinate_data(event, event_ref):
-                self.__writeln(1, key)
-            else:
-                self.__writeln(1, key, 'Y')
-            if event.get_description().strip() != "":
-                self.__writeln(2, 'TYPE', event.get_description())
-            self.__dump_event_stats(event, event_ref)
+            if event:
+                if event_has_subordinate_data(event, event_ref):
+                    self.__writeln(1, key)
+                else:
+                    self.__writeln(1, key, 'Y')
+                if event.get_description().strip() != "":
+                    self.__writeln(2, 'TYPE', event.get_description())
+                self.__dump_event_stats(event, event_ref)
 
     def __change(self, timeval, level):
         """
@@ -1286,6 +1318,8 @@ class GedcomWriter(UpdateCallback):
             return
 
         src = self.dbase.get_source_from_handle(src_handle)
+        if src is None:
+            return
 
         # Reference to the source
         self.__writeln(level, "SOUR", "@%s@" % src.get_gramps_id())
@@ -1347,7 +1381,7 @@ class GedcomWriter(UpdateCallback):
             if form:
                 self.__writeln(level+1, 'FORM', form)
             self.__writeln(level+1, 'TITL', photo_obj.get_description())
-            self.__writeln(level+1, 'FILE', path)
+            self.__writeln(level+1, 'FILE', path, limit=255)
 
             self.__note_references(photo_obj.get_note_list(), level+1)
 
@@ -1365,6 +1399,7 @@ class GedcomWriter(UpdateCallback):
             +2 LONG <PLACE_LONGITUDE> {1:1}
             +1 <<NOTE_STRUCTURE>> {0:M} 
         """
+        if place is None: return
         place_name = place.get_title()
         self.__writeln(level, "PLAC", place_name.replace('\r', ' '))
         longitude = place.get_longitude()
