@@ -22,11 +22,11 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ExportXml.py 12842 2009-07-28 04:28:12Z pez4brian $
+# $Id: ExportXml.py 15692 2010-08-09 13:17:38Z dsblank $
 
 """
 Contains the interface to allow a database to get written using
-GRAMPS' XML file format.
+Gramps' XML file format.
 """
 
 #-------------------------------------------------------------------------
@@ -39,7 +39,7 @@ import shutil
 import os
 import codecs
 from xml.sax.saxutils import escape
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 
 #------------------------------------------------------------------------
@@ -48,21 +48,21 @@ from gettext import gettext as _
 #
 #------------------------------------------------------------------------
 import logging
-log = logging.getLogger(".WriteXML")
+LOG = logging.getLogger(".WriteXML")
 
 #-------------------------------------------------------------------------
 #
-# load GRAMPS libraries
+# load Gramps libraries
 #
 #-------------------------------------------------------------------------
 import gen.lib 
-from BasicUtils import UpdateCallback
-from gen.db.exceptions import GrampsDbWriteFailure
+from gen.updatecallback import UpdateCallback
+from gen.db.exceptions import DbWriteFailure
 import const
+import constfunc
 from QuestionDialog import ErrorDialog
-import ExportOptions
+from ExportOptions import WriterOptionBox
 import gen.proxy
-from gen.plug import PluginManager, ExportPlugin
 import libgrampsxml
 
 #-------------------------------------------------------------------------
@@ -81,14 +81,18 @@ except:
 strip_dict = dict.fromkeys(range(9)+range(12,20))
 
 def escxml(d):
-    return escape(d, { '"' : '&quot;' } )
+    return escape(d, 
+                  {'"' : '&quot;',
+                   '<' : '&lt;',
+                   '>' : '&gt;',
+                   })
 
 #-------------------------------------------------------------------------
 #
 #
 #
 #-------------------------------------------------------------------------
-class GrampsDbXmlWriter(UpdateCallback):
+class GrampsXmlWriter(UpdateCallback):
     """
     Writes a database to the XML file.
     """
@@ -122,7 +126,7 @@ class GrampsDbXmlWriter(UpdateCallback):
         base = os.path.dirname(filename)
         if os.path.isdir(base):
             if not os.access(base, os.W_OK) or not os.access(base, os.R_OK):
-                raise GrampsDbWriteFailure(
+                raise DbWriteFailure(
                          _('Failure writing %s') % filename,
                          _("The database cannot be saved because you do "
                            "not have permission to write to the directory. "
@@ -132,7 +136,7 @@ class GrampsDbXmlWriter(UpdateCallback):
             
         if os.path.exists(filename):
             if not os.access(filename, os.W_OK):
-                raise GrampsDbWriteFailure(
+                raise DbWriteFailure(
                         _('Failure writing %s') % filename,
                         _("The database cannot be saved because you do "
                            "not have permission to write to the file. "
@@ -150,8 +154,8 @@ class GrampsDbXmlWriter(UpdateCallback):
             else:
                 g = open(filename,"w")
         except IOError,msg:
-            print str(msg)
-            raise GrampsDbWriteFailure((_('Failure writing %s') % filename,
+            LOG.warn(str(msg))
+            raise DbWriteFailure((_('Failure writing %s') % filename,
                                        str(msg)))
             return 0
 
@@ -201,15 +205,14 @@ class GrampsDbXmlWriter(UpdateCallback):
         
         self.g.write('<?xml version="1.0" encoding="UTF-8"?>\n')
         self.g.write('<!DOCTYPE database '
-                     'PUBLIC "-//GRAMPS//DTD GRAMPS XML %s//EN"\n'
+                     'PUBLIC "-//Gramps//DTD Gramps XML %s//EN"\n'
                      '"http://gramps-project.org/xml/%s/grampsxml.dtd">\n'
                      % (libgrampsxml.GRAMPS_XML_VERSION, 
                         libgrampsxml.GRAMPS_XML_VERSION))
         self.g.write('<database xmlns="http://gramps-project.org/xml/%s/">\n'
                      % libgrampsxml.GRAMPS_XML_VERSION)
         self.g.write("  <header>\n")
-        self.g.write('    <created date="%04d-%02d-%02d\"' %
-                     (date[0],date[1],date[2]) )
+        self.g.write('    <created date="%04d-%02d-%02d\"' % date[:3])
         self.g.write(" version=\"" + self.version + "\"")
         self.g.write("/>\n")
         self.g.write("    <researcher>\n")
@@ -252,7 +255,7 @@ class GrampsDbXmlWriter(UpdateCallback):
 
         if family_len > 0:
             self.g.write("  <families>\n")
-            for handle in self.db.get_family_handles():
+            for handle in self.db.iter_family_handles():
                 family = self.db.get_family_from_handle(handle)
                 self.write_family(family,2)
                 self.update()
@@ -376,7 +379,8 @@ class GrampsDbXmlWriter(UpdateCallback):
             for number, name,fmt_str,active in self.db.name_formats:
                 self.g.write('%s<format number="%d" name="%s" '
                              'fmt_str="%s" active="%d"/>\n'
-                             % ('    ', number, name, fmt_str, int(active)) )
+                             % ('    ', number, 
+                                escxml(name), escxml(fmt_str), int(active)) )
             self.g.write("  </name-formats>\n")
 
     def fix(self,line):
@@ -1080,8 +1084,7 @@ class GrampsDbXmlWriter(UpdateCallback):
             self.g.write('%s<coord long="%s" lat="%s"/>\n'
                          % ("  "*(index+1), longitude, lat))
         self.dump_location(main_loc)
-        for loc in place.get_alternate_locations():
-            self.dump_location(loc)
+        map(self.dump_location, place.get_alternate_locations())
         self.write_media_list(place.get_media_list(), index+1)
         self.write_url_list(place.get_url_list())
         self.write_note_list(place.get_note_list(), index+1)
@@ -1104,7 +1107,10 @@ class GrampsDbXmlWriter(UpdateCallback):
         elif self.strip_photos == 2 and (len(path)>0 and os.path.isabs(path)):
             drive, path = os.path.splitdrive(path)
             path = path[1:]
-                
+        if constfunc.win():
+            # Always export path with \ replaced with /. Otherwise import
+            # from Windows to Linux of gpkg's path to images does not work. 
+            path = path.replace('\\','/')
         self.g.write('%s<file src="%s" mime="%s"%s/>\n'
                      % ("  "*(index+1), self.fix(path), mime_type, desc_text))
         self.write_attribute_list(obj.get_attribute_list())
@@ -1191,13 +1197,13 @@ def export_data(database, filename, option_box=None, callback=None):
 # XmlWriter
 #
 #-------------------------------------------------------------------------
-class XmlWriter(GrampsDbXmlWriter):
+class XmlWriter(GrampsXmlWriter):
     """
     Writes a database to the XML file.
     """
 
     def __init__(self, dbase, callback, strip_photos, compress=1):
-        GrampsDbXmlWriter.__init__(
+        GrampsXmlWriter.__init__(
             self, dbase, strip_photos, compress, const.VERSION, callback)
         
     def write(self, filename):
@@ -1206,26 +1212,8 @@ class XmlWriter(GrampsDbXmlWriter):
         """
         ret = 0 #False
         try:
-            ret = GrampsDbXmlWriter.write(self, filename)
-        except GrampsDbWriteFailure, msg:
+            ret = GrampsXmlWriter.write(self, filename)
+        except DbWriteFailure, msg:
             (m1,m2) = msg.messages()
             ErrorDialog(m1, m2)
         return ret
-
-#------------------------------------------------------------------------
-#
-# Register with the plugin system
-#
-#------------------------------------------------------------------------
-_description = _('GRAMPS XML export is a complete archived XML backup of the' 
-                 ' GRAMPS database without the media object files.'
-                 ' Suitable for backup purposes.')
-_config = (_('GRAMPS XML export options'), ExportOptions.WriterOptionBox)
-
-pmgr = PluginManager.get_instance()
-plugin = ExportPlugin(name            = _('GRAMPS _XML database'), 
-                      description     = _description,
-                      export_function = export_data,
-                      extension       = "gramps",
-                      config          = _config )
-pmgr.register_plugin(plugin)
