@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Check.py 14617 2010-03-04 14:11:59Z ldnp $
+# $Id: Check.py 15983 2010-10-14 11:31:15Z ldnp $
 
 """Tools/Database Repair/Check and Repair Database"""
 
@@ -30,6 +30,7 @@
 #-------------------------------------------------------------------------
 from __future__ import with_statement
 import os
+import sys
 import cStringIO
 
 from gen.ggettext import gettext as _
@@ -525,7 +526,7 @@ class CheckIntegrity(object):
                 self.bad_photo.append(ObjectId)
 
             def fs_ok_clicked(obj):
-                name = Utils.get_unicode_path(fs_top.get_filename())
+                name = Utils.get_unicode_path_from_file_chooser(fs_top.get_filename())
                 if os.path.isfile(name):
                     obj = self.db.get_object_from_handle(ObjectId)
                     obj.set_path(name)
@@ -552,8 +553,10 @@ class CheckIntegrity(object):
             photo_name = Utils.media_path_full(self.db, obj.get_path())
             if photo_name is not None and photo_name != "" and not Utils.find_file(photo_name):
                 if cl:
+                    # Convert to file system encoding before prining
+                    fn = os.path.basename(photo_name).encode(sys.getfilesystemencoding())
                     print "Warning: media file %s was not found." \
-                        % os.path.basename(photo_name)
+                        % fn
                     self.bad_photo.append(ObjectId)
                 else:
                     if missmedia_action == 0:
@@ -1627,7 +1630,8 @@ class Report(ManagedWindow.ManagedWindow):
     
     def __init__(self, uistate, text, cl=0):
         if cl:
-            print text
+            # Convert to file system encoding before prining
+            print text.encode(sys.getfilesystemencoding())
             return
 
         ManagedWindow.ManagedWindow.__init__(self, uistate, [], self)
